.. _builtin-data-stores:

====================
Available Clients
====================

.. _store_redis:

Redis
================================

.. automodule:: pulsar.apps.data.stores.redis


.. _store_pulsar:

PulsarDs
================================

It has the same implementation as :ref:`redis client <store_redis>`.


.. _store_couchdb:

CouchDb
===========

.. automodule:: pulsar.apps.data.stores.couchdb.store
